@@ -1,3 +1,5 @@
+use indexkv::StreamError;
+
 #[derive(thiserror::Error, Debug)]
 pub enum Error {
 	#[error("year missing")]
@@ -20,7 +22,14 @@ pub enum Error {
 	NotFound(u64),
 	#[error("cache failure")]
 	Cache(#[from] indexkv::Error)
-	//#[error("general failure")]
-	//Other(#[from] Box<dyn std::error::Error>)
+}
+
+impl From<StreamError<Error>> for Error {
+	fn from(other: StreamError<Error>) -> Self {
+		match other {
+			StreamError::Internal(e) => Self::from(e),
+			StreamError::Caller(e) => e
+		}
+	}
 }
 
