@@ -5,6 +5,7 @@ use crate::Title;
 use crate::TitleType;
 
 #[derive(Debug, Eq, PartialEq)]
+/// Represents a movie from IMDB.  Pared down from [Title] based on fields that make sense for movies.
 pub struct Movie {
 	pub imdb_id: u64,
 	pub title: String,
@@ -15,13 +16,14 @@ pub struct Movie {
 }
 
 impl Movie {
+	#[allow(dead_code)] // Used in tests
 	pub(crate) fn new(imdb_id: u64, title: &str, is_adult: bool, year: u16, runtime_minutes: Option<u16>, genres: &[&str]) -> Self {
 		Self{
-			imdb_id: imdb_id,
+			imdb_id,
 			title: title.to_string(),
-			is_adult: is_adult,
-			year: year,
-			runtime_minutes: runtime_minutes,
+			is_adult,
+			year,
+			runtime_minutes,
 			genres: genres.iter().map(|s| s.to_string()).collect()
 		}
 	}
@@ -43,7 +45,7 @@ impl TryFrom<&Title> for Movie {
 					Some(v) => v,
 					None => match input.end_year {
 						Some(v) => v,
-						None => return Err(Error::YearMissing.into())
+						None => return Err(Error::YearMissing)
 					}
 				},
 				//year: input.start_year,
@@ -78,10 +80,8 @@ pub(crate) fn title_matches_movie_name_and_year(title: &Result<Title, Error>, na
 		} else {
 			return false;
 		}
-		if(title.primary_title != name) {
-			if(title.original_title != name) {
-				return false;
-			}
+		if(title.primary_title != name && title.original_title != name) {
+			return false;
 		}
 		return true;
 	}
