@@ -7,6 +7,7 @@ use crate::Title;
 use crate::TitleType;
 
 #[derive(Eq, PartialEq)]
+/// Represents a TV series from IMDB.
 pub struct Show {
 	pub imdb_id: u64,
 	pub title: String,
@@ -34,16 +35,18 @@ impl std::fmt::Debug for Show /* {{{ */ {
 } // }}}
 
 impl Show {
+	#[allow(dead_code)] // Used in tests
+	#[allow(clippy::too_many_arguments)] // Only a convenience function for tests; this is fine
 	pub(crate) fn new(imdb_id: u64, title: &str, is_adult: bool, start_year: u16, end_year: Option<u16>, runtime_minutes: Option<u16>, genres: &[&str], episodes: &[Episode]) -> Self /* {{{ */ {
 		Self{
-			imdb_id: imdb_id,
+			imdb_id,
 			title: title.to_string(),
-			is_adult: is_adult,
-			start_year: start_year,
-			end_year: end_year,
-			runtime_minutes: runtime_minutes,
+			is_adult,
+			start_year,
+			end_year,
+			runtime_minutes,
 			genres: genres.iter().map(|s| s.to_string()).collect(),
-			episodes: episodes.iter().map(|e| e.clone()).collect()
+			episodes: episodes.to_vec()
 		}
 	} // }}}
 
@@ -62,7 +65,7 @@ impl TryFrom<&Title> for Show /* {{{ */ {
 				is_adult: input.is_adult,
 				start_year: match input.start_year {
 					Some(v) => v,
-					None => return Err(Error::YearMissing.into())
+					None => return Err(Error::YearMissing)
 				},
 				end_year: input.end_year,
 				runtime_minutes: input.runtime_minutes,
@@ -82,6 +85,7 @@ impl TryFrom<Title> for Show /* {{{ */ {
 } // }}}
 
 #[derive(Clone, Debug, Eq, PartialEq)]
+/// Represents an episode of a TV series from IMDB.  Pared down from [Title] and EpisodeLink based on fields that make sense for an individual episode.
 pub struct Episode {
 	pub season: u16,
 	pub episode: u16,
@@ -106,13 +110,14 @@ impl Ord for Episode /* {{{ */ {
 } // }}}
 
 impl Episode {
+	#[allow(dead_code)] // Used in tests
 	pub(crate) fn new(season: u16, episode: u16, imdb_id: u64, title: &str, runtime_minutes: Option<u16>) -> Self /* {{{ */ {
 		Self{
-			season: season,
-			episode: episode,
-			imdb_id: imdb_id,
+			season,
+			episode,
+			imdb_id,
 			title: title.to_string(),
-			runtime_minutes: runtime_minutes
+			runtime_minutes
 		}
 	} // }}}
 
@@ -121,11 +126,11 @@ impl Episode {
 			TitleType::Episode => Ok(Self{
 				season: match link.season {
 					Some(v) => v,
-					None => return Err(Error::SeasonMissing.into())
+					None => return Err(Error::SeasonMissing)
 				},
 				episode: match link.episode {
 					Some(v) => v,
-					None => return Err(Error::EpisodeMissing.into())
+					None => return Err(Error::EpisodeMissing)
 				},
 				imdb_id: title.imdb_id,
 				title: title.primary_title,
@@ -148,10 +153,8 @@ pub(crate) fn title_matches_show_name_and_year(title: &Result<Title, Error>, nam
 		} else {
 			return false;
 		}
-		if(title.primary_title != name) {
-			if(title.original_title != name) {
-				return false;
-			}
+		if(title.primary_title != name && title.original_title != name) {
+			return false;
 		}
 		return true;
 	}
