@@ -6,7 +6,9 @@ use serde_repr::Deserialize_repr;
 use serde_repr::Serialize_repr;
 
 #[derive(Debug, Deserialize, Serialize)]
+/// Represents a single title in IMDB; a "title" can be a show, an episode of a show, a movie, etc.  See [TitleType] for a list.
 pub struct Title {
+	/// ID from IMDB, with the leading "tt" removed
 	pub imdb_id: u64,
 	pub title_type: TitleType,
 	pub primary_title: String,
@@ -34,8 +36,11 @@ impl From<TitleFromImdb> for Title /* {{{ */ {
 	}
 } // }}}
 
-#[derive(Debug, Deserialize_repr, Eq, PartialEq, Serialize_repr, strum::ToString)]
+#[derive(Debug, Deserialize_repr, Eq, PartialEq, Serialize_repr, strum::Display)]
 #[repr(u8)]
+/// Identifies the type of a [Title].  IMDB has more possible values that, because this crate is opinionated, we collapse down.
+///
+/// For example, "episode", "tvEpisode", and "tvPilot" all become TitleType::Episode.
 pub enum TitleType {
 	Short = 0,
 	Movie = 1,
@@ -117,7 +122,7 @@ impl<'de> Deserialize<'de> for TitleTypeFromImdb {
 			"audiobook" => Self::Audiobook,
 			"radioSeries" => Self::RadioSeries,
 			"radioEpisode" => Self::RadioEpisode,
-			s => return Err(serde::de::Error::invalid_value(Unexpected::Str(&s), &"'short', 'episode', 'tvEpisode', 'tvPilot', 'movie', 'tvMovie', 'tvSeries', 'tvMiniSeries', 'tvShort', 'tvSpecial', 'video', 'videoGame', 'audiobook', 'radioSeries', 'radioEpisode'"))
+			s => return Err(serde::de::Error::invalid_value(Unexpected::Str(s), &"'short', 'episode', 'tvEpisode', 'tvPilot', 'movie', 'tvMovie', 'tvSeries', 'tvMiniSeries', 'tvShort', 'tvSpecial', 'video', 'videoGame', 'audiobook', 'radioSeries', 'radioEpisode'"))
 		})
 	}
 }
